========
Example
========

Here we provide some examples on how to use LINNA


- `multivariate gaussian distribution`_
    Demonstrates how to use LINNA to sample a 2d gaussian distribution
- `cosmolike_3x2pt_analyese`_
    Tutorial on how to do 3x2pt analyese using LINNA and cosmolike

.. _multivariate gaussian distribution: notebooks/multivariate_gaussian_distribution.ipynb
.. _cosmolike_3x2pt_analyese: notebooks/cosmolike_3x2pt_analyese.ipynb




.. toctree::
   :maxdepth: 2
   :hidden:

